v3.x.y - Jumeaux
Author: tadashi-aikawa
Description: Check difference between two responses of API.

コンテンツにスキップ

# Version 3.0～4.0

Version3.0～4.0までのリリースノートです。

## 3.1.1

`2022-03-31`

`jumeaux viewer`コマンドが利用できない不具合を修正しました

## 3.1.0

`2022-03-06`

URLのホスト部分を無視して文字列比較てきるtemplate用関数を追加しました

- 環境によってレスポンスのURLにおけるホストが変わる場合に便利です
- 詳細はequals_without_hostをご覧ください

## 3.0.1

`2022-02-18`

依存関係のバージョンによってJumeauxが実行できない不具合を修正しました

## 3.0.0

`2021-06-03`

レスポンスヘッダの比較ができるようになりました

- デフォルトではレスポンスヘッダの保存/比較はしません (今まで通り)
  - configの`judge_response_header`を`true`にする必要があります
- レスポンスヘッダはreport > trial内に保存されます
  - 詳細はResponseSummary > `headers`をご覧ください
- config > `ignore_response_header_keys`で指定したkeyは差分があっても無視できます
  - trial > `diffs_by_cognition`のような機能はありません